#!/bin/sh


MIN=$1
MAX=$2
AVG=$3
NRAY=$4
PERIOD=$5
S2=$6
M2=$7
FILE=$8
ID=$9
VEL=`echo ${AVG} | awk '{printf "%.4f",$1}' `

echo DOmap.sh ${MIN} ${MAX} ${AVG}

#####
#    create a polar cps map
#####

# PMX  give extreme percentage for plot
# LMIN is minimum number of km in a cell
# DP is increment for percentage notation
PMX=20
LMIN=10.0
DP=5.0

makecpt -Cpolar -T-${PMX}/${PMX}/1 > mypolar.cpt


#####
#   make a file of
#   Longitude Latitude Percentage
#####
cat > awkit << EOF
{
if(\$4 > ${LMIN}){frac = 100.0*(\$3 - ${AVG})/${AVG} ; if (frac < -${PMX})frac = -${PMX}; if (frac > ${PMX}) frac = ${PMX}; printf "%.4f %.4f %.1f 0.2 \n", \$1, \$2, -frac }
}
EOF
cat ${FILE} | awk -f awkit > pct

PROJ2="-R0/10.5/0/11/ -Jx3 -P -V"
#
PROJ="-R-128/-60/25/52 -JM-92.0/38/30c -P -V"
#
#
rm -f ps.rper05
# for GMT4
gmtset BASEMAP_TYPE FANCY OUTPUT_DEGREE_FORMAT -D PLOT_DEGREE_FORMAT ddd.xx MEASURE_UNIT cm  PAPER_MEDIA ledger+

pscoast   ${PROJ}  -B5/2 -W -K -Na -Dh  -K -G240   >> ps.rper05
psxy ./pct -Sc -Cmypolar.cpt  -: $PROJ -W0.01p -O  -K >> ps.rper05
pscoast   ${PROJ}  -B5/2 -W -K -Na -Dh -O -K   >> ps.rper05

#####
#   plot a scale
#   first blank out an area
#   then split the scale
#####
psxy  ${PROJ} -O -: -V -G255 -W1p -A -L -K >> ps.rper05 << EOF
27.0 -127.2
27.0 -122.7
35.0 -122.7
35.0 -127.2
EOF

pstext -: ${PROJ}  -O  -K >> ps.rper05 << EOF
34.7 -126.0 12 0.0 5 TC  %
EOF
psscale -O -K  -Cmypolar.cpt -B${DP}::   -D0.5c/3.0c/3.0c/0.5c >> ps.rper05


#####
#	annotate the bottom of the figure
#####
pstext ${PROJ2} -Y-3 -O   >> ps.rper05 << EOF
1.0 0.5 12 0.0 5 5 ${ID}: Period=${PERIOD}s Vavg=${VEL}km/s ${NRAY} Rays used=${NRAY} Vmin=${MIN} Vmax=${MAX}
9.2 1.5 36 0.0 5 RB ${PERIOD}
EOF
#pstext ${PROJ2} -Y-3 -O  -K >> ps.rper05 << EOF
#1.0 0.5 12 0.0 5 5 ${PERIOD} S
#1.7 0.5 12 0.0 5 5 Vavg = ${VEL} km/s
#3.2 0.5 12 0.0 5 5 ${NRAY} Rays used
#4.2 0.5 12 0.0 5 5 Vmin = ${MIN}
#5.2 0.5 12 0.0 5 5 Vmax = ${MAX}
#EOF

